Package **stucancommon**
=========================

Python library to access a CAN bus, dependency for the *xcomcan* package

Prerequisites
----------------

Please read the complete documentation available on : `Studer Innotec SA`_ *-> Support -> Download Center -> Software and Updates -> Communication protocols Xcom-CAN*

Getting Started
----------------

1. Package installation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. code-block:: console

    $ pip install xcomcan

2. Going further
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Please visit `Read The Docs`_ of *xcomcan* package for next steps.

Authors
----------------

**Studer Innotec SA** - *Initial work* - `Studer Innotec SA`_

License
----------------

This project is licensed under the MIT License - see the `LICENSE`_ file for details

.. External References:
.. _Studer Innotec SA: https://www.studer-innotec.com
.. _Read The Docs: https://xcomcan.readthedocs.io/en/latest/index.html
.. _LICENSE: https://xcomcan.readthedocs.io/en/latest/license.html
